nxp-pac

Crates

git

Versions

mimxrt1064

Flavors

Ope

Enum Ope 

#[repr(u8)]
pub enum Ope { OPE_0 = 0, OPE_1 = 1, }

Variants



OPE_0 = 0

CMPO is not available on the associated CMPO output pin. If the comparator does not own the pin, this field has no effect.



OPE_1 = 1

CMPO is available on the associated CMPO output pin. The comparator output (CMPO) is driven out on the associated CMPO output pin if the comparator owns the pin. If the comparator does not own the field, this bit has no effect.

Implementations

Source

impl Ope

pub const fn from_bits(val: u8) -> Ope

pub const fn to_bits(self) -> u8