#[repr(u8)]pub enum Pmode {
PMODE_0 = 0,
PMODE_1 = 1,
}Variants
PMODE_0 = 0
Low-Speed (LS) Comparison mode selected. In this mode, CMP has slower output propagation delay and lower current consumption.
PMODE_1 = 1
High-Speed (HS) Comparison mode selected. In this mode, CMP has faster output propagation delay and higher current consumption.
Implementations